;================================================================================
;
;PHILLIPS/NXP MULTIPLE CHANNEL UART BLOCK & CHANNEL BASICS
;
;	
;	Abbreviations used in comments are as follows:
;
;	    -------------
;	    C/T  Counter/timer
;	    IP   Input port
;	    LSB  Least significant byte
;	    MSB  Most significant byte
;	    OP   Output port
;	    (R)  Read only
;	    RxD  Receiver
;	    TxD  Transmitter
;	    (W)  Write only
;	    -------------
;
;	NXP dual & quadruple channel UARTs are organized into functional blocks,
;	each block containing 2 communications channels, plus control & status
;	registers.  Device layouts are as follows:
;
;	    26C92
;	    28L92
;	      |
;	      +> BLOCK A: $00-$0F
;	               |
;	               +> channel A registers: $00-$03
;	               +> block registers:     $04-$07
;	               +> channel B registers: $08-$0B
;	               *> block registers:     $0C-$0F
;
;	    28C94
;	      |
;	      +> BLOCK A: $00-$0F
;	      |        |
;	      |        +> channel A registers: $00-$03
;	      |        +> block registers:     $04-$07
;	      |        +> channel B registers: $08-$0B
;	      |        *> block registers:     $0C-$0F
;	      |
;	      +> BLOCK B: $10-$1F
;	      |        |
;	      |        +> channel A registers: $10-$13
;	      |        +> block registers:     $14-$17
;	      |        +> channel B registers: $18-$1B
;	      |        *> block registers:     $1C-$1F
;	      |
;	      +> CONTROL: $20-$3F
;
;	In the above, offsets are relative to the device's base address in the
;	memory map.  The 26C92 & 28L92 occupy 16 bytes of address space, where-
;	as the 28C94 occupies 64 bytes of address space.
;
;	The relationship between UART channels & external communication ports is
;	defined as follows:
;
;	                        Comm
;	    Block    Channel    Port
;	    ------------
;	      A         A         A
;	      A         B         B
;	      B         A         C
;	      B         B         D
;	    ------------
;
;	As used in POC V1, port A corresponds to the console port & port B corr-
;	esponds to the auxiliary port.  Ports C & D are uncommitted.
;	
;
nx_bkadx =0                    ;block A device index
nx_bkbdx =nx_bkadx + s_nxpblk  ;block B device index (28C94)
nx_dvctl =nx_bkbdx + s_nxpblk  ;device control index (28C94)
nx_chabx =0                    ;channel A block index
nx_chbbx =nx_chabx + s_nxpch   ;channel B block index
nx_chadx =nx_chabx + nx_bkadx  ;comm port A device index
nx_chbdx =nx_chbbx + nx_bkadx  ;comm port B device index
nx_chcdx =nx_chabx + nx_bkbdx  ;comm port C device index (28C94)
nx_chddx =nx_chbbx + nx_bkbdx  ;comm port D device index (28C94)
;
;
;	per channel register offsets...
;
nx_mr    =0                    ;mode select
nx_sr    =1                    ;status (R)
nx_csr   =1                    ;clock select (W)
nx_cr    =2                    ;command (W)
nx_rhr   =3                    ;RxD FIFO (R)
nx_thr   =3                    ;TxD FIFO (W)
;
;
;	per block register offsets...
;
nx_ipcr  =4                    ;IP change (R)
nx_acr   =4                    ;auxiliary control (W)
nx_isr   =5                    ;interrupt status (R)
nx_imr   =5                    ;interrupt enable (W)
nx_ctu   =6                    ;C/T MSB value (R)
nx_ctl   =7                    ;C/T LSB value (R)
nx_crur  =6                    ;C/T MSB preset (W)
nx_crlr  =7                    ;C/T LSB preset (W)
nx_ureg  =12                   ;user-defined or...
nx_opr   =12                   ;I/O port configuration...
;
;	
;	The use of block register 12 depends on the device.  See the applicable
;	data sheets for specifics.  The POC firmware makes no reference to this
;	register.
;	
;
nx_ipsr  =13                   ;IP status (R)
nx_opcr  =13                   ;OP configuration (W)
nx_sct   =14                   ;start C/T (R)
nx_sopb  =14                   ;set OP bits (W)
nx_rct   =15                   ;stop C/T (R)
nx_ropb  =15                   ;reset OP bits (W)
;
;================================================================================
;
;PHILLIPS/NXP MULTIPLE CHANNEL UART COMMUNICATION PORT REGISTERS
;
nx_csra  =nx_csr + nx_chadx    ;A: clock select (W)
nx_cra   =nx_cr  + nx_chadx    ;A: command (W)
nx_mra   =nx_mr  + nx_chadx    ;A: mode select
nx_rhra  =nx_rhr + nx_chadx    ;A: RxD FIFO (R)
nx_sra   =nx_sr  + nx_chadx    ;A: status (R)
nx_thra  =nx_thr + nx_chadx    ;A: TxD FIFO (W)
nx_csrb  =nx_csr + nx_chbdx    ;B: clock select (W)
nx_crb   =nx_cr  + nx_chbdx    ;B: command (W)
nx_mrb   =nx_mr  + nx_chbdx    ;B: mode select
nx_rhrb  =nx_rhr + nx_chbdx    ;B: RxD FIFO (R)
nx_srb   =nx_sr  + nx_chbdx    ;B: status (R)
nx_thrb  =nx_thr + nx_chbdx    ;B: TxD FIFO (W)
nx_csrc  =nx_csr + nx_chcdx    ;C: clock select (W)
nx_crc   =nx_cr  + nx_chcdx    ;C: command (W)
nx_mrc   =nx_mr  + nx_chcdx    ;C: mode select
nx_rhrc  =nx_rhr + nx_chcdx    ;C: RxD FIFO (R)
nx_src   =nx_sr  + nx_chcdx    ;C: status (R)
nx_thrc  =nx_thr + nx_chcdx    ;C: TxD FIFO (W)
nx_csrd  =nx_csr + nx_chddx    ;D: clock select (W)
nx_crd   =nx_cr  + nx_chddx    ;D: command (W)
nx_mrd   =nx_mr  + nx_chddx    ;D: mode select
nx_rhrd  =nx_rhr + nx_chddx    ;D: RxD FIFO (R)
nx_srd   =nx_sr  + nx_chddx    ;D: status (R)
nx_thrd  =nx_thr + nx_chddx    ;D: TxD FIFO (W)
;
;================================================================================
;
;PHILLIPS/NXP MULTIPLE CHANNEL UART BLOCK CONTROL/STATUS REGISTERS
;
nx_ipcra =nx_ipcr + nx_bkadx   ;A: IP change (R)
nx_acra  =nx_acr  + nx_bkadx   ;A: auxiliary control (W)
nx_isra  =nx_isr  + nx_bkadx   ;A: interrupt status (R)
nx_imra  =nx_imr  + nx_bkadx   ;A: interrupt enable (W)
nx_ctua  =nx_ctu  + nx_bkadx   ;A: C/T MSB value (R)
nx_ctla  =nx_ctl  + nx_bkadx   ;A: C/T LSB value (R)
nx_crura =nx_crur + nx_bkadx   ;A: C/T MSB preset (W)
nx_crlra =nx_crlr + nx_bkadx   ;A: C/T LSB preset (W)
nx_urega =nx_ureg + nx_bkadx   ;A: user-defined
nx_opra  =nx_opr  + nx_bkadx   ;A: I/O port configuration
nx_ipsra =nx_ipsr + nx_bkadx   ;A: IP status (R)
nx_opcra =nx_opcr + nx_bkadx   ;A: OP configuration (W)
nx_scta  =nx_sct  + nx_bkadx   ;A: start C/T (R)
nx_sopba =nx_sopb + nx_bkadx   ;A: set OP bits (W)
nx_rcta  =nx_rct  + nx_bkadx   ;A: stop C/T (R)
nx_ropba =nx_ropb + nx_bkadx   ;A: reset OP bits (W)
nx_ipcrb =nx_ipcr + nx_bkbdx   ;B: IP change (R)
nx_acrb  =nx_acr  + nx_bkbdx   ;B: auxiliary control (W)
nx_isrb  =nx_isr  + nx_bkbdx   ;B: interrupt status (R)
nx_imrb  =nx_imr  + nx_bkbdx   ;B: interrupt enable (W)
nx_ctub  =nx_ctu  + nx_bkbdx   ;B: C/T MSB value (R)
nx_ctlb  =nx_ctl  + nx_bkbdx   ;B: C/T LSB value (R)
nx_crurb =nx_crur + nx_bkbdx   ;B: C/T MSB preset (W)
nx_crlrb =nx_crlr + nx_bkbdx   ;B: C/T LSB preset (W)
nx_oprb  =nx_opr  + nx_bkbdx   ;B: I/O port configuration
nx_ipsrb =nx_ipsr + nx_bkbdx   ;B: IP status (R)
nx_opcrb =nx_opcr + nx_bkbdx   ;B: OP configuration (W)
nx_sctb  =nx_sct  + nx_bkbdx   ;B: start C/T (R)
nx_sopbb =nx_sopb + nx_bkbdx   ;B: set OP bits (W)
nx_rctb  =nx_rct  + nx_bkbdx   ;B: stop C/T (R)
nx_ropbb =nx_ropb + nx_bkbdx   ;B: reset OP bits (W)
;
	.end